Gammapy
=======

A Python Package for Gamma-ray Astronomy

* Code: https://github.com/gammapy/gammapy
* Docs: https://gammapy.readthedocs.org/


Status reports for developers:

.. image:: https://travis-ci.org/gammapy/gammapy.png?branch=master
    :target: https://travis-ci.org/gammapy/gammapy
    :alt: Test Status

.. image:: https://coveralls.io/repos/gammapy/gammapy/badge.png
    :target: https://coveralls.io/r/gammapy/gammapy
    :alt: Code Coverage

.. image:: https://landscape.io/github/gammapy/gammapy/master/landscape.png
    :target: https://landscape.io/github/gammapy/gammapy/master
    :alt: Code Health
